﻿-- Name:		extradetach.lua
-- Description:	Implements the extradetach specialization
-- Author:		Noobgetier (omgz@gmx.de)
-- Version:		1.2
-- Date:		2013-02-04
-- Change log:	1.0 - inital release
--				1.1 - added detach sound playback
--				1.2 - helper bug fixed

extradetach = {};

function extradetach.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Fillable, specializations);
end;

function extradetach:load(xmlFile)
	self.extradetach = {};
	self.extradetach.isAttached = false;
	self.detachSound = SpecializationUtil.callSpecializationsFunction("detachSound");
end;

function extradetach:readStream(streamId, connection)
end;

function extradetach:writeStream(streamId, connection)
end;

function extradetach:keyEvent(unicode, sym, modifier, isDown)
end;

function extradetach:update(dt)
	if self:getIsActive() and self.isClient then
		if self:getIsActiveForInput() then
			if InputBinding.hasEvent(InputBinding.EXTRA_DETACH_KEY) then
				if self.extradetach.isAttached then
					self:detachSound(self.attacherVehicle);
					self.attacherVehicle:detachImplementByObject(self);
				end;
			end;
		end;
	end;
end;

function extradetach:updateTick(dt)
	if self:getIsActive() and self.isClient then
		if self:getIsActiveForInput() then
			if self.attacherVehicle ~= nil then
				if self.isSelected then
					self.extradetach.isAttached = true;
				else
					self.extradetach.isAttached = false;
				end;
			end;
		end;
	end;
end;

function extradetach:draw()
	if self.isClient then
		if self.extradetach.isAttached then
			g_currentMission:addHelpButtonText(Fillable.EXTRA_DETACH_KEY, InputBinding.EXTRA_DETACH_KEY);
		end;
	end;
end;
	
function extradetach:mouseEvent(posX, posY, isDown, isUp, button)
end;

function extradetach:onDetach()
end;

function extradetach:onAttach()
end;

function extradetach:onEnter()
end;
	
function extradetach:delete()
end;

function extradetach:onLeave() 
end;

function extradetach:detachSound(av)
	if av.attacherVehicle ~= nil and type(av.attacherVehicle) == "table" then
		self:detachSound(av.attacherVehicle);
	else
		av:playDetachSound();
	end;
end;
